Package: maps
Title: Draw Geographical Maps
Version: 3.4.3
Date: 2025-05-15
Description: Display of maps.  Projection code and larger maps are in
             separate packages ('mapproj' and 'mapdata').
Depends: R (>= 3.5.0)
Imports: graphics, utils
LazyData: yes
Suggests: mapproj (>= 1.2-0), mapdata (>= 2.3.0), sf, rnaturalearth
License: GPL-2
URL: https://github.com/adeckmyn/maps
BugReports: https://github.com/adeckmyn/maps/issues
Authors@R: c(person(given  = c("Richard", "A."),
                    family = "Becker",
                    role   = "aut",
                    comment= "Original S code"),
             person(given  = c("Allan", "R."),
                    family = "Wilks",
                    role   = "aut",
                    comment= "Original S code"),
             person(given  = "Ray",
                    family = "Brownrigg",
                    role   = c("trl", "aut"),
                    comment= "R version"),
             person(given  = c("Thomas", "P."),
                    family = "Minka",
                    role   = "aut",
                    comment= "Enhancements"),
             person(given  = "Alex",
                    family = "Deckmyn",
                    role   = c("aut", "cre"),
                    comment= c(ORCID="0009-0002-2010-8310"),
                    email  = "alex.deckmyn@meteo.be"))
NeedsCompilation: yes
Repository: CRAN
Packaged: 2025-05-19 08:35:55 UTC; alex
Author: Richard A. Becker [aut] (Original S code),
  Allan R. Wilks [aut] (Original S code),
  Ray Brownrigg [trl, aut] (R version),
  Thomas P. Minka [aut] (Enhancements),
  Alex Deckmyn [aut, cre] (ORCID:
    <https://orcid.org/0009-0002-2010-8310>)
Maintainer: Alex Deckmyn <alex.deckmyn@meteo.be>
Date/Publication: 2025-05-26 17:40:02 UTC
